@@ -4,7 +4,7 @@ Usage:
     hosthome          [-h | --help]
     hosthome empezar  [--verbose]
     hosthome eliminar [--verbose] 
-    hosthome info    <id:str>
+    hosthome info id
     hosthome         [-v | --version]
 
 Argumentos:
